GateConfig

Trait GateConfig 

pub trait GateConfig {
    const SUMMARY_MIN_L1_WORDS: usize;
    const CURSOR_MIN_SUMMARY_WORDS: usize;
}
Compile-time tuning of the two summary-scan gates.

By default, the allocator uses DefaultGates.

Required Associated Constants

const SUMMARY_MIN_L1_WORDS: usize

Minimum L1 words an order must have to be given a summary segment.

const CURSOR_MIN_SUMMARY_WORDS: usize

Minimum summary words an order must have before the frontier cursor is used.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors